## COW: CSV on the Web Converters
**Authors:**    Albert Meroño-Peñuela, Roderick van der Weerdt, Rinke Hoekstra, Kathrin Dentler, Auke Rijpma, Richard Zijdeman

**Copyright:**  Vrije Universiteit Amsterdam, Utrecht University, International Institute for Social History

**License:**    MIT License (see [license.txt](license.txt))


> COW is an integrated CSV to RDF converter, using [CSVW](https://www.w3.org/TR/tabular-data-primer/) and [nanopublications](http://nanopub.org/)

### Documentation & Installation

Documentation and Installation instructions for COW are maintained in this GitHub repository (under <docs>), and published through [Read the Docs](http://readthedocs.org) at <http://csvw-converter.readthedocs.io/en/latest/>. As an addition to this documentation the [wiki](https://github.com/CLARIAH/COW/wiki) provides more hands-on examples of transposing csv's into Linked Data

To build the documentation from source, change into the `docs` directory, and run `make html`. This should produce an HTML version of the documentation in the `_build/html` directory.
